describe('preprocessors require2js', function() {
	var File, chai, createPreprocessor, expect, require2js, logger, process, helpers;
	chai = require('chai');
	helpers = require('./helpers/request_cache');
	chai.use(helpers);
	expect = chai.expect;
	//require2js = require('../lib/index');
	require2js = require('../lib/index')['preprocessor:ng-request2js'][1];
	logger = {
		create: function() {
			return {
				debug: function() {}
			};
		}
	};
	//console.log('require2js: ', require2js);
	process = null;
	File = function(path, mtime) {
		this.path = path;
		this.originalPath = path;
		this.contentPath = path;
		this.mtime = mtime;
		this.isUrl = false;
	};

	createPreprocessor = function(config) {
		if (config == null) {
			config = {};
		}
		return require2js(logger, '/base', config);
	};

	beforeEach(function() {
		return process = createPreprocessor();
	});

	it('should convert html to js code', function(done) {
		var HTML, file;
		file = new File('/base/path/file.html');
		HTML = '<html>test me!</html>';
		process(HTML, file, function(processedContent) {
			console.log('foobar',typeof processedContent);
			expect(processedContent).to.defineModule('path/file.html').and.to.defineTemplateId('path/file.html').and.to.haveContent(HTML);
			done();
		});
	});
	xit('should change path to *.js', function(done) {
		var file;
		file = new File('/base/path/file.html');
		process('', file, function(processedContent) {
			expect(file.path).to.equal('/base/path/file.html.js');
			done();
		});
	});

	xit('should not append *.js to a processed file\'s path more than once', function(done) {
		var file;
		file = new File('/base/path/file.html');
		process('', file, function(processedContent) {
			process('', file, function(processedContent) {
				expect(file.path).to.equal('/base/path/file.html.js');
				done();
			});
		});
	});

	xit('should preserve new lines', function(done) {
		var file;
		file = new File('/base/path/file.html');
		process('first\nsecond', file, function(processedContent) {
			expect(processedContent).to.defineModule('path/file.html').and.to.defineTemplateId('path/file.html').and.to.haveContent('first\nsecond');
			done();
		});
	});

	xit('should preserve Windows new lines', function(done) {
		var file;
		file = new File('/base/path/file.html');
		process('first\r\nsecond', file, function(processedContent) {
			expect(processedContent).to.not.contain('\r');
			done();
		});
	});

	xit('should preserve the backslash character', function(done) {
		var file;
		file = new File('/base/path/file.html');
		process('first\\second', file, function(processedContent) {
			expect(processedContent).to.defineModule('path/file.html').and.to.defineTemplateId('path/file.html').and.to.haveContent('first\\second');
			done();
		});
	});
});
